@@ -180,11 +180,9 @@ Gtk2-GladeXML,dev-perl/gtk2-gladexml
 Gtk2-Spell,dev-perl/gtk2-spell
 Gtk2-TrayIcon,dev-perl/gtk2-trayicon
 Gtk2-TrayManager,dev-perl/gtk2-traymanager
-Gtk2Fu,dev-perl/gtk2-fu
 Image-ExifTool,media-libs/exiftool
 Image-Info,dev-perl/ImageInfo
 Image-Size,dev-perl/ImageSize
-Inline-Files,dev-perl/inline-files
 Locale-Maketext-Fuzzy,dev-perl/locale-maketext-fuzzy
 Math-Pari,dev-perl/math-pari
 Module-Info,dev-perl/module-info
